@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.2801";
+our $VERSION = "1.29";
 
 use v5.14;
 use warnings;
@@ -302,12 +302,11 @@ sub read_files {
 	for my $data (@data) {
 	    my @line = split /\n/, $data;
 	    @line = insert_space @line if $obj->paragraph;
-	    my @length;
 	    my $length = do {
 		if ($obj->table) {
 		    max map length, @line;
 		} else {
-		    $obj->expand_tab(\@line, \@length);
+		    $obj->expand_tab(\@line, \my @length);
 		    max @length;
 		}
 	    };
@@ -325,7 +324,7 @@ sub expand_tab {
     my $obj = shift;
     my($dp, $lp) = @_;
     for (@$dp) {
-	($_, my($dmy, $length)) = ansi_fold($_, -1, expand => 1);
+	($_, my($dmy, $length)) = ansi_fold $_, -1, expand => 1;
 	push @$lp, $length;
     }
 }
@@ -441,9 +440,9 @@ sub table_out {
     my @lines  = map { [ split $split, $_, $obj->table_columns_limit ] } @_;
     my @length = map { [ map { ansi_width $_ } @$_ ] } @lines;
     my @max    = map { max @$_ } xpose @length;
-    my @align  = newlist(count => 0+@max, default => '-',
+    my @align  = newlist(count => int @max, default => '-',
 			 [ map --$_, split /,/, $obj->table_right ] => '');
-    my @format = map { '%' . $align[$_] . $max[$_] . 's' } 0 .. $#max;
+    my @format = map "%$align[$_]$max[$_]s", 0 .. $#max;
     for my $line (@lines) {
 	next unless @$line;
 	my @fmt = @format[0 .. $#{$line}];
